==> ugene_33.0+dfsg.orig.tar.xz: ugene-33.0/src/plugins/circular_view/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>CircularViewSettingsWidget</name>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="20"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="38"/>
        <source>Show title</source>
        <translation>Показывать названия</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="48"/>
        <source>Show length</source>
        <translation>Показывать длину</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="64"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="84"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="104"/>
        <source>Attribute</source>
        <translation>Признак</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="150"/>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="153"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="193"/>
        <source>Inside</source>
        <translation>Внутри</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="198"/>
        <source>Outside</source>
        <translation>Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="203"/>
        <source>Inside/Outside</source>
        <translation>Внутри/Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="208"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="292"/>
        <source>Label font size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="270"/>
        <source>Show ruler line</source>
        <translation>Показывать шкалу</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="222"/>
        <source>Font size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="254"/>
        <source>Label position</source>
        <translation>Позиция ярлыка</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="280"/>
        <source>Show coordinates</source>
        <translation>Показывать координаты</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="335"/>
        <source>There are no displayed Circular Views, so settings are hidden.</source>
        <translation>Нет круговых видов, настройки скрыты.</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="363"/>
        <source>Open Circular View(s)</source>
        <translation>Открыть круговой вид(ы)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="114"/>
        <location filename="../src/CircularViewImageExportTask.cpp" line="128"/>
        <source>Circular view</source>
        <translation>Круговой вид</translation>
    </message>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="166"/>
        <source>Include position marker</source>
        <translation>Включить позицию</translation>
    </message>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="167"/>
        <source>Include selection</source>
        <translation>Включить выделение</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidgetFactory.cpp" line="57"/>
        <source>Circular View Settings</source>
        <translation>Настройки кругового вида</translation>
    </message>
</context>
<context>
    <name>SetSequenceOriginDialog</name>
    <message>
        <location filename="../src/SetSequenceOriginDialog.ui" line="32"/>
        <source>Set sequence origin</source>
        <translation>Установить последовательность отсчета</translation>
    </message>
    <message>
        <location filename="../src/SetSequenceOriginDialog.ui" line="40"/>
        <source>New origin:</source>
        <translation>Отсчет с:</translation>
    </message>
    <message>
        <location filename="../src/SetSequenceOriginDialog.ui" line="47"/>
        <source>New sequence origin point. All annotations will be shifted relative to new origin point.</source>
        <translation>Новая точка отсчета. Все аннотации будут сдвинуты относительно новой точки отсчета.</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewAction</name>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="353"/>
        <source>Show circular view</source>
        <translation>Показать круговой вид</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewContext</name>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="102"/>
        <source>Save circular view as image...</source>
        <translation>Сохранить круговой вид как изображение...</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="107"/>
        <source>Set new sequence origin...</source>
        <translation>Установить последовательность отсчета...</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="120"/>
        <source>Toggle circular views</source>
        <translation>Переключить круговые виды</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="276"/>
        <source>Remove circular view</source>
        <translation>Удалить круговой вид</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="287"/>
        <source>Show circular view</source>
        <translation>Показать круговой вид</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewImageExportController</name>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="123"/>
        <source>List of Circular Views is empty!</source>
        <translation>Список круговых видов пуст!</translation>
    </message>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="146"/>
        <source>Sequence</source>
        <translation>Последовательность</translation>
    </message>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="149"/>
        <source>Sequence context is NULL!</source>
        <translation>Sequence context is NULL!</translation>
    </message>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="150"/>
        <source>Sequence Gobject is NULL</source>
        <translation>Sequence Gobject is NULL</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewImageExportTaskFactory</name>
    <message>
        <source>List of Circular Views is empty!</source>
        <translation type="obsolete">Список круговых видов пуст!</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation type="obsolete">Последовательность</translation>
    </message>
    <message>
        <source>Sequence context is NULL!</source>
        <translation type="obsolete">Sequence context is NULL!</translation>
    </message>
    <message>
        <source>Sequence Gobject is NULL</source>
        <translation type="obsolete">Sequence Gobject is NULL</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewPlugin</name>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="74"/>
        <source>CircularView</source>
        <translation>Круговой вид</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="74"/>
        <source>Enables drawing of DNA sequences using circular representation</source>
        <translation>Круговой вид ДНК последовательности</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="79"/>
        <source>OPWidgetFactoryRegistry is NULL</source>
        <translation>OPWidgetFactoryRegistry is NULL</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewRenderArea</name>
    <message>
        <location filename="../src/CircularView.cpp" line="472"/>
        <source>CircularView is NULL</source>
        <translation>CircularView is NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularView.cpp" line="474"/>
        <source>Circular view settings are NULL</source>
        <translation>Circular view settings are NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularView.cpp" line="494"/>
        <source>circular view size %1 %2</source>
        <translation>Размер кругового вида %1 %2</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewSettingsWidget</name>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="42"/>
        <source>Circular view settings is NULL</source>
        <translation>Circular view settings is NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="65"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="113"/>
        <source>Inside</source>
        <translation>Внутри</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="68"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="116"/>
        <source>Outside</source>
        <translation>Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="71"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="122"/>
        <source>Inside/Outside</source>
        <translation>Внутри/Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="74"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="119"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="131"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="134"/>
        <source>Ruler</source>
        <translation>Шкала</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="137"/>
        <source>Annotations</source>
        <translation>Аннотации</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewSettingsWidgetFactory</name>
    <message>
        <location filename="../src/CircularViewSettingsWidgetFactory.cpp" line="37"/>
        <source>Circular view context is NULL</source>
        <translation>Circular view context is NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidgetFactory.cpp" line="42"/>
        <source>Object view is NULL</source>
        <translation>Object view is NULL</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewSplitter</name>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="57"/>
        <location filename="../src/CircularViewSplitter.cpp" line="59"/>
        <source>Zoom In</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="62"/>
        <location filename="../src/CircularViewSplitter.cpp" line="64"/>
        <source>Zoom Out</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="66"/>
        <location filename="../src/CircularViewSplitter.cpp" line="68"/>
        <source>Fit To Full View</source>
        <translation>Полный размер</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="70"/>
        <location filename="../src/CircularViewSplitter.cpp" line="72"/>
        <source>Save circular view as image</source>
        <translation>Сохранить круговой вид как изображение</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="74"/>
        <location filename="../src/CircularViewSplitter.cpp" line="76"/>
        <source>Show/hide restriction sites map</source>
        <translation>Показать/скрыть карту сайтов рестрикции</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="166"/>
        <source>Circular View is NULL</source>
        <translation>Circular View is NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="168"/>
        <source>Circular View viewport is NULL</source>
        <translation>Circular View viewport is NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="170"/>
        <source>Scroll area is NULL</source>
        <translation>Scroll area is NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="217"/>
        <source>Sequence context is NULL</source>
        <translation>Sequence context is NULL</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="219"/>
        <source>Sequence obejct is NULL</source>
        <translation>Sequence obejct is NULL</translation>
    </message>
</context>
<context>
    <name>U2::RestrctionMapWidget</name>
    <message>
        <location filename="../src/RestrictionMapWidget.cpp" line="69"/>
        <location filename="../src/RestrictionMapWidget.cpp" line="80"/>
        <source>site</source>
        <translation>участок</translation>
    </message>
    <message>
        <location filename="../src/RestrictionMapWidget.cpp" line="69"/>
        <location filename="../src/RestrictionMapWidget.cpp" line="80"/>
        <source>sites</source>
        <translation>участки</translation>
    </message>
    <message>
        <location filename="../src/RestrictionMapWidget.cpp" line="103"/>
        <source>Restriction Sites Map</source>
        <translation>Карта сайтов рестрикции</translation>
    </message>
</context>
<context>
    <name>U2::ShiftSequenceStartTask</name>
    <message>
        <location filename="../src/ShiftSequenceStartTask.cpp" line="50"/>
        <source>ShiftSequenceStartTask</source>
        <translation>ShiftSequenceStartTask</translation>
    </message>
    <message>
        <location filename="../src/ShiftSequenceStartTask.cpp" line="65"/>
        <source>Document is locked</source>
        <translation>Документ заблокирован</translation>
    </message>
</context>
</TS>

==> ugene_51.0+dfsg.orig.tar.xz: ugene-51.0/src/plugins/circular_view/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>CircularViewSettingsWidget</name>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="20"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="38"/>
        <source>Show title</source>
        <translation>Показывать названия</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="48"/>
        <source>Show length</source>
        <translation>Показывать длину</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="64"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="84"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="104"/>
        <source>Attribute</source>
        <translation>Признак</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="150"/>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="153"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="193"/>
        <source>Inside</source>
        <translation>Внутри</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="198"/>
        <source>Outside</source>
        <translation>Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="203"/>
        <source>Inside/Outside</source>
        <translation>Внутри/Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="208"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="292"/>
        <source>Label font size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="270"/>
        <source>Show ruler line</source>
        <translation>Показывать шкалу</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="222"/>
        <source>Font size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="254"/>
        <source>Label position</source>
        <translation>Позиция ярлыка</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="280"/>
        <source>Show coordinates</source>
        <translation>Показывать координаты</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="335"/>
        <source>There are no displayed Circular Views, so settings are hidden.</source>
        <translation>Нет круговых видов, настройки скрыты.</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.ui" line="363"/>
        <source>Open Circular View(s)</source>
        <translation>Открыть круговой вид(ы)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="111"/>
        <location filename="../src/CircularViewImageExportTask.cpp" line="125"/>
        <source>Circular view</source>
        <translation>Круговой вид</translation>
    </message>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="163"/>
        <source>Include position marker</source>
        <translation>Включить позицию</translation>
    </message>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="164"/>
        <source>Include selection</source>
        <translation>Включить выделение</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidgetFactory.cpp" line="58"/>
        <source>Circular View Settings</source>
        <translation>Настройки кругового вида</translation>
    </message>
</context>
<context>
    <name>SetSequenceOriginDialog</name>
    <message>
        <location filename="../src/SetSequenceOriginDialog.ui" line="32"/>
        <source>Set sequence origin</source>
        <translation>Установка точки отсчета</translation>
    </message>
    <message>
        <location filename="../src/SetSequenceOriginDialog.ui" line="40"/>
        <source>New origin:</source>
        <translation>Отсчет с:</translation>
    </message>
    <message>
        <location filename="../src/SetSequenceOriginDialog.ui" line="47"/>
        <source>New sequence origin point. All annotations will be shifted relative to new origin point.</source>
        <translation>Новая точка отсчета. Все аннотации будут сдвинуты относительно новой точки отсчета.</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewAction</name>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="347"/>
        <source>Show circular view</source>
        <translation>Показать круговой вид</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewContext</name>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="101"/>
        <source>Save circular view as image...</source>
        <translation>Сохранить круговой вид как изображение...</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="106"/>
        <source>Set new sequence origin...</source>
        <translation>Установить точку отсчета...</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="118"/>
        <source>Toggle circular views</source>
        <translation>Переключить круговые виды</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="273"/>
        <source>Remove circular view</source>
        <translation>Удалить круговой вид</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="283"/>
        <source>Show circular view</source>
        <translation>Показать круговой вид</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewImageExportController</name>
    <message>
        <location filename="../src/CircularViewImageExportTask.cpp" line="143"/>
        <source>Sequence</source>
        <translation>Последовательность</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewPlugin</name>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="74"/>
        <source>CircularView</source>
        <translation>Круговой вид</translation>
    </message>
    <message>
        <location filename="../src/CircularViewPlugin.cpp" line="74"/>
        <source>Enables drawing of DNA sequences using circular representation</source>
        <translation>Круговой вид ДНК последовательности</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewRenderArea</name>
    <message>
        <location filename="../src/CircularView.cpp" line="384"/>
        <source>circular view size %1 %2</source>
        <translation>Размер кругового вида %1 %2</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewSettingsWidget</name>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="64"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="112"/>
        <source>Inside</source>
        <translation>Внутри</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="67"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="115"/>
        <source>Outside</source>
        <translation>Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="70"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="121"/>
        <source>Inside/Outside</source>
        <translation>Внутри/Снаружи</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="73"/>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="118"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="130"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="133"/>
        <source>Ruler</source>
        <translation>Шкала</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSettingsWidget.cpp" line="136"/>
        <source>Annotations</source>
        <translation>Аннотации</translation>
    </message>
</context>
<context>
    <name>U2::CircularViewSplitter</name>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="49"/>
        <location filename="../src/CircularViewSplitter.cpp" line="51"/>
        <source>Zoom In</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="54"/>
        <location filename="../src/CircularViewSplitter.cpp" line="56"/>
        <source>Zoom Out</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="58"/>
        <location filename="../src/CircularViewSplitter.cpp" line="60"/>
        <source>Fit To Full View</source>
        <translation>Полный размер</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="62"/>
        <location filename="../src/CircularViewSplitter.cpp" line="64"/>
        <source>Save circular view as image</source>
        <translation>Сохранить круговой вид как изображение</translation>
    </message>
    <message>
        <location filename="../src/CircularViewSplitter.cpp" line="66"/>
        <location filename="../src/CircularViewSplitter.cpp" line="68"/>
        <source>Show/hide restriction sites map</source>
        <translation>Показать/скрыть карту сайтов рестрикции</translation>
    </message>
</context>
<context>
    <name>U2::RestrctionMapWidget</name>
    <message>
        <location filename="../src/RestrictionMapWidget.cpp" line="65"/>
        <location filename="../src/RestrictionMapWidget.cpp" line="75"/>
        <source>site</source>
        <translation>участок</translation>
    </message>
    <message>
        <location filename="../src/RestrictionMapWidget.cpp" line="65"/>
        <location filename="../src/RestrictionMapWidget.cpp" line="75"/>
        <source>sites</source>
        <translation>участки</translation>
    </message>
    <message>
        <location filename="../src/RestrictionMapWidget.cpp" line="97"/>
        <source>Restriction Sites Map</source>
        <translation>Карта сайтов рестрикции</translation>
    </message>
</context>
<context>
    <name>U2::ShiftSequenceStartTask</name>
    <message>
        <location filename="../src/ShiftSequenceStartTask.cpp" line="42"/>
        <source>ShiftSequenceStartTask</source>
        <translation>ShiftSequenceStartTask</translation>
    </message>
    <message>
        <location filename="../src/ShiftSequenceStartTask.cpp" line="48"/>
        <source>New sequence origin is the same as the old one</source>
        <translation>New sequence origin is the same as the old one</translation>
    </message>
    <message>
        <location filename="../src/ShiftSequenceStartTask.cpp" line="54"/>
        <source>Sequence start position is out of range</source>
        <translation>Sequence start position is out of range</translation>
    </message>
    <message>
        <location filename="../src/ShiftSequenceStartTask.cpp" line="59"/>
        <source>Document is locked</source>
        <translation>Документ заблокирован</translation>
    </message>
</context>
</TS>
